package org.diligentproject.searchservice.clients;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import org.diligentproject.searchservice.searchlibrary.searchstatus.SearchStatus;
import org.diligentproject.searchservice.searchlibrary.searchui.SearchUI;

public class SearchManagerClient {
	static String serviceURI=null;
	static boolean search=false;
	static String query=null;
	static String outFile=null;
	static String inFile=null;
	
	public static void main(String []args) throws Exception{
		try{
			if(!parseInput(args)){
				System.out.println("[ -poll -input <filename> | -location <host>:<port> -search -query <query> -output <filename> ]");
				return;
			}
			
			if(!search){
				SearchUI ui=new SearchUI();
				ui.associate(readFile(inFile));
				SearchStatus stat=ui.pollStatus();
				System.out.println(stat.message);
				if(stat.qStatus==SearchStatus.DONE){
					writeFile(stat.resultSetEPR,outFile);
				}
			}
			else{
				SearchUI ui=new SearchUI(serviceEndPoint());
				ui.connect();
				ui.submitQuery(query);
				writeFile(ui.getStatusEPR(),outFile);
			}
		}catch (Exception e){
			e.printStackTrace();
		}
	}

	private static boolean parseInput(String []args){
		try{
			for (int i=0;i<args.length;i+=1){
				if (args[i].equalsIgnoreCase("-location")){
					if(serviceURI!=null) return false;
					i+=1;
					serviceURI=args[i];
				}
				if (args[i].equalsIgnoreCase("-poll")){
					i+=1;
					search=false;
				}
				if (args[i].equalsIgnoreCase("-search")){
					i+=1;
					search=true;
				}
				if (args[i].equalsIgnoreCase("-output")){
					if(outFile!=null) return false;
					i+=1;
					outFile=args[i];
				}
				if (args[i].equalsIgnoreCase("-input")){
					if(outFile!=null) return false;
					i+=1;
					outFile=args[i];
				}
				if (args[i].equalsIgnoreCase("-query")){
					if(query!=null) return false;
					i+=1;
					query=args[i];
				}
			}
			if (search && (outFile==null || query ==null || serviceURI==null)) return false;
			if (!search && (inFile==null)) return false;
			return true;
		}catch(Exception e){
			e.printStackTrace();
			return false;
		}
	}
	
	private static String readFile(String filename) throws Exception{
		FileReader fr=new FileReader(filename);
		BufferedReader br=new BufferedReader(fr);
		StringBuilder buf=new StringBuilder();
		String line =br.readLine();
		while (line!=null){
			buf.append(line);
			line=br.readLine();
		}
		br.close();
		fr.close();
		return buf.toString();
	}
	
	private static void writeFile(String text,String filename) throws Exception{
		FileWriter fw=new FileWriter(filename);
		BufferedWriter bw=new BufferedWriter(fw);
		bw.write(text);
		bw.close();
		fw.close();
	}
	
	private static String serviceEndPoint(){
		return "http://"+serviceURI+"/wsrf/services/diligentproject/searchservice/SearchManagerService";
	}
}
